@@ -305,7 +305,7 @@ class TestDecorators(CleanUp,
             def __init__(self, result):
                 pass
 
-            def decorateExternalMapping(self, orig_object, result):
+            def decorateExternalMapping(self, _orig_object, result):
                 result['decorated'] = True
 
         @component.adapter(object, IRequest)
@@ -314,7 +314,7 @@ class TestDecorators(CleanUp,
             def __init__(self, result, request):
                 pass
 
-            def decorateExternalMapping(self, orig_object, result):
+            def decorateExternalMapping(self, _orig_object, result):
                 result['req_decorated'] = True
 
 
@@ -712,7 +712,7 @@ class TestToExternalObject(ExternalizationLayerTest):
 
     def test_mapping_of_non_primitives(self):
         class Foo(object):
-            def toExternalObject(self, **kwargs):
+            def toExternalObject(self, **_kwargs):
                 return 42
         assert_that(toExternalObject({'key': Foo()}),
                     is_({'key': 42}))
@@ -784,7 +784,7 @@ class TestToExternalObject(ExternalizationLayerTest):
         class O(object):
             ext_obj = None
 
-            def toExternalObject(self, **kwargs):
+            def toExternalObject(self, **_kwargs):
                 return {"Hi": 42,
                         "kid": toExternalObject(self.ext_obj)}
 
@@ -810,7 +810,7 @@ class TestToExternalObject(ExternalizationLayerTest):
             def __str__(self):
                 return "creator"
 
-            def toExternalObject(self, *args, **kwargs):
+            def toExternalObject(self, *_args, **_kwargs):
                 return to_standard_external_dictionary(self)
 
         result = toExternalObject(O())
@@ -821,6 +821,29 @@ class TestToExternalObject(ExternalizationLayerTest):
         s = to_json_representation_externalized(result)
         assert_that(s, is_('{"Class": "O", "Creator": "creator"}'))
 
+    def test_externalize_OOBTree(self):
+        from BTrees import family64
+        bt = family64.OO.BTree()
+        bt['key'] = 'value'
+        result = toExternalObject(bt)
+        assert_that(result, is_(dict))
+        assert_that(result, is_({'Class': 'OOBTree', 'key': 'value'}))
+
+    def test_externalize_PersistentMapping(self):
+        from persistent.mapping import PersistentMapping
+        pm = PersistentMapping()
+        pm['key'] = 'value'
+        result = toExternalObject(pm)
+        assert_that(result, is_(dict))
+        assert_that(result, is_({'Class': 'PersistentMapping', 'key': 'value'}))
+
+    def test_externalize_IIBTree(self):
+        from BTrees import family64
+        bt = family64.II.BTree()
+        bt[1] = 2
+        result = toExternalObject(bt)
+        assert_that(result, is_(dict))
+        assert_that(result, is_({'Class': 'LLBTree', 1: 2}))
 
 @NoPickle
 class DoNotPickleMe(object):
